@@ -112,7 +112,11 @@ def interactive_loop(
 
         # Parse multiple action sequences
         cli_parser = CLIParser()
-        cli_parser.parse(shlex_split(command_line))
+        try:
+            cli_parser.parse(shlex_split(command_line))
+        except ValueError as error:
+            print("Error: {}".format(error))
+            continue
 
         # Loop through action sequences
         command_sequences = RewindableList(cli_parser.get_sequences())
@@ -123,7 +127,7 @@ def interactive_loop(
         while True:
             try:
                 command = command_sequences.pop_next()
-                logging.info("Current command = {}".format(command))
+                logging.info("Current sequence = {}".format(command))
             except IndexError:
                 break
 
@@ -267,7 +271,7 @@ def interactive_loop(
                 command.pop(0)
                 alias_name = command.pop(0)
                 if alias_name == "alias":
-                    print("Cannot create alias for 'alias'")
+                    print("Not permitted: cannot create alias for 'alias'")
                     continue
                 if len(command) == 0:
                     if am.create_alias(alias_name, None):
@@ -346,7 +350,7 @@ def interactive_loop(
                         continue
 
                 action = args.pop(0).lower()
-                logging.info("Action = '{}'; args = '{}'".format(action, args))
+                logging.info("Action = '{}'; args = {}".format(action, args))
                 exit_code, output, error_msg = run_command(
                     speaker,
                     action,
@@ -554,13 +558,17 @@ class AliasProcessor:
             )
 
         alias_actions = am.action(alias_name)
-        action_elements = shlex_split(alias_actions)
+        try:
+            action_elements = shlex_split(alias_actions)
+        except ValueError as error:
+            print("Error: {}".format(error))
+            return False
 
         cli_parser = CLIParser()
         cli_parser.parse(action_elements)
         sequences = cli_parser.get_sequences()
 
-        logging.info("Unpacking the alias '{} -> '{}'".format(alias_name, sequences))
+        logging.info("Unpacking the alias '{}' -> '{}'".format(alias_name, sequences))
 
         index = command_list.index()
         for idx, sequence in enumerate(sequences, start=1):
@@ -642,6 +650,7 @@ def _rescan(use_local_speaker_list=False, max=False):
     elif max:
         logging.info("Full network rescan at max strength (timeout = 10.0s)")
         speaker_cache().scan(reset=True, scan_timeout_override=10.0)
+        _print_speaker_list(use_local_speaker_list=use_local_speaker_list)
     else:
         logging.info("Full network rescan")
         speaker_cache().scan(reset=True)
